@@ -23,11 +23,16 @@
 #   Guillaume Pellerin <yomguy@parisson.com>
 
 
-import optparse, math, sys
-import ImageFilter, ImageChops, Image, ImageDraw, ImageColor, ImageEnhance
-import numpy
+import optparse, math, sys, numpy
+
+try:
+    import ImageFilter, ImageChops, Image, ImageDraw, ImageColor, ImageEnhance
+except ImportError:
+    from PIL import ImageFilter, ImageChops, Image, ImageDraw, ImageColor, ImageEnhance
+
 from timeside.core import FixedSizeInputAdapter
 
+
 default_color_schemes = {
     'default': {
         'waveform': [(50,0,200), (0,220,80), (255,224,0), (255,0,0)],
